# OperationalInsights

> see https://aka.ms/autorest

This is the AutoRest configuration file for OperationalInsights.



---
## Getting Started
To build the SDK for OperationalInsights, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration



### Basic Information
These are the global settings for the OperationalInsights API.

``` yaml
title: OperationalInsightsManagementClient
description: Operational Insights Client
openapi-type: arm
tag: package-2015-11-preview
```


### Tag: package-2015-11-preview

These settings apply only when `--tag=package-2015-11-preview` is specified on the command line.

``` yaml $(tag) == 'package-2015-11-preview'
input-file:
- Microsoft.OperationalInsights/preview/2015-11-01-preview/OperationalInsights.json
```

### Tag: package-2015-03

These settings apply only when `--tag=package-2015-03` is specified on the command line.

``` yaml $(tag) == 'package-2015-03'
input-file:
- Microsoft.OperationalInsights/stable/2015-03-20/OperationalInsights.json
```

---
# Code Generation


## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-python
  - repo: azure-sdk-for-js
  - repo: azure-sdk-for-node
  - repo: azure-sdk-for-ruby
    after_scripts:
      - bundle install && rake arm:regen_all_profiles['azure_mgmt_operational_insights']
```


## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

```yaml $(csharp)
csharp:
  # last generated using AutoRest.1.0.0-Nightly20170126
  azure-arm: true
  namespace: Microsoft.Azure.Management.OperationalInsights
  payload-flattening-threshold: 1
  license-header: MICROSOFT_MIT_NO_VERSION
  output-folder: $(csharp-sdks-folder)/OperationalInsights/Management/Management.OperationalInsights/Generated
  clear-output-folder: true
```

## Python

These settings apply only when `--python` is specified on the command line.
Please also specify `--python-sdks-folder=<path to the root directory of your azure-sdk-for-python clone>`.
Use `--python-mode=update` if you already have a setup.py and just want to update the code itself.

``` yaml $(python)
python-mode: create
python:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  payload-flattening-threshold: 2
  namespace: azure.mgmt.loganalytics
  package-name: azure-mgmt-loganalytics
  title: LogAnalyticsManagementClient
  description: The Log Analytics Client.
  clear-output-folder: true
```
``` yaml $(python) && $(python-mode) == 'update'
python:
  no-namespace-folders: true
  output-folder: $(python-sdks-folder)/azure-mgmt-loganalytics/azure/mgmt/loganalytics
```
``` yaml $(python) && $(python-mode) == 'create'
python:
  basic-setup-py: true
  output-folder: $(python-sdks-folder)/azure-mgmt-loganalytics
```

## Go

See configuration in [readme.go.md](./readme.go.md)

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
azure-arm: true
fluent: true
namespace: com.microsoft.azure.management.operationalinsights
license-header: MICROSOFT_MIT_NO_CODEGEN
payload-flattening-threshold: 1
output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-operationalinsights
```



### Java multi-api

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-2015-03
  - tag: package-2015-11-preview
```

### Tag: package-2015-03 and java

These settings apply only when `--tag=package-2015-03 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2015-03' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.operationalinsights.v2015_03_20
  output-folder: $(azure-libraries-for-java-folder)/operationalinsights/resource-manager/v2015_03_20
regenerate-manager: true
generate-interface: true
```

### Tag: package-2015-11-preview and java

These settings apply only when `--tag=package-2015-11-preview --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2015-11-preview' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.operationalinsights.v2015_11_01_preview
  output-folder: $(azure-libraries-for-java-folder)/operationalinsights/resource-manager/v2015_11_01_preview
regenerate-manager: true
generate-interface: true
```


## Suppression

``` yaml
directive:
  - from: OperationalInsights.json
    suppress: R3006  # BodyTopLevelProperties/R3006/RPCViolation
    reason: properties etag defined as eTag in model
```
